from setuptools import setup

setup(name='avimu_probability',
      version='1.0',
      description='Binomial and Gaussian distributions',
      packages=['avimu_probability'],
      author='Avi Mukesh',
      zip_safe=False)
